/*
        Copyright (c) 2004 on behalf of the EU EGEE Project:
        The European Organization for Nuclear Research (CERN),
        Istituto Nazionale di Fisica Nucleare (INFN), Italy
        Datamat Spa, Italy
        Centre National de la Recherche Scientifique (CNRS), France
        CS Systeme d'Information (CSSI), France
        Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
        Universiteit van Amsterdam (UvA), Netherlands
        University of Helsinki (UH.HIP), Finland
        University of Bergen (UiB), Norway
        Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom

        CEConsumer.hh: header file for a C++ providing consumer APIs

        Authors: Alvise Dorigo <alvise.dorigo@pd.infn.it>
        Version info: $Id: CEConsumer.h,v 1.23 2005/10/04 09:31:54 adorigo Exp $
*/
#ifndef __CECONSUMER__
#define __CECONSUMER__

#define NOTIFY ns1__Notify
#define NOTIFICATION _ns2__Notification
#define NOTIFYRESPONSE ns1__NotifyResponse

#define SOAP_RECV_TIMEOUT 60
#define SOAP_SEND_TIMEOUT 60

#include "monitor_consumer_soapStub.h"
#include "Topic.h"
#include <string>
#include <vector>

class CEConsumer {

private:
  int localPort;
  int localSocket;
  int clientSocket;
  std::string errorMessage;
  std::string errorCode;
  struct soap *SOAP;
  std::string clientIP;
  std::string clientName;
  time_t EventTimestamp;
  Topic* topic;
  int messageSize;
  int EventID;
  std::string EventProducer;
  std::vector<std::string> Messages;
  int messageCounter;
  CEConsumer(const CEConsumer&) {}
  CEConsumer operator=(const CEConsumer&) { return *this; }
  void setResponse(int, int, time_t, std::string, std::vector<std::string>*);
  void setError(void);

public:
  CEConsumer(int);
  virtual ~CEConsumer();

  bool bind(void);
  bool accept(void);
  void reset(void);
  std::string getClientIP() const;
  std::string getClientName() const;
  int getClientSocket() const;
  int getLocalPort() const;
  int getLocalSocket() const;
  bool serve(void);
  const char *getNextEventMessage();
  Topic* getEventTopic() const;
  int getEventID() const;
  int getMessageSize() const;
  std::string getEventProducer() const;
  std::string getErrorMessage() const;
  std::string getErrorCode() const;
  inline void setRecvTimeout(const int& t) { SOAP->recv_timeout = t; }
  inline void setSendTimeout(const int& t) { SOAP->send_timeout = t; }
};

#endif
